@@ -326,7 +326,7 @@ class BasePafy(object):
 
     @property
     def mix(self):
-        """ The playlist for the related YouTube mix. Returns a dict containing Pafy objects. """
+        """ The playlist for the related YouTube mix. Returns a Playlist object. """
         if self._mix_pl is None:
             try:
                 self._mix_pl = get_playlist2("RD" + self.videoid)
@@ -436,7 +436,7 @@ class BaseStream(object):
         self._fsize = None
         self._active = False
 
-    def generate_filename(self, meta=False):
+    def generate_filename(self, meta=False, max_length=None):
         """ Generate filename. """
         ok = re.compile(r'[^/]')
 
@@ -446,7 +446,12 @@ class BaseStream(object):
         filename = "".join(x if ok.match(x) else "_" for x in self.title)
 
         if meta:
-            filename += "-%s-%s" % (self._parent.videoid, self.itag)
+            filename += " - %s - %s" % (self._parent.videoid, self.itag)
+
+        if max_length:
+            max_length = max_length + 1 + len(self.extension)
+            if len(filename) > max_length:
+                filename = filename[:max_length-3] + '...'
 
         filename += "." + self.extension
         return filename
@@ -571,13 +576,13 @@ class BaseStream(object):
         savedir = filename = ""
 
         if filepath and os.path.isdir(filepath):
-            savedir, filename = filepath, self.generate_filename()
+            savedir, filename = filepath, self.generate_filename(max_length=256-len('.temp'))
 
         elif filepath:
             savedir, filename = os.path.split(filepath)
 
         else:
-            filename = self.generate_filename(meta=meta)
+            filename = self.generate_filename(meta=meta, max_length=256-len('.temp'))
 
         filepath = os.path.join(savedir, filename)
         temp_filepath = filepath + ".temp"
